// $Id: sanity_checks.cc,v 1.6 2002/11/15 08:21:40 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "writers/WriterBase.hh"

int main()
{  safemap<std::string,const WriterBase *>::const_iterator i,j;
   for (i=Writer.begin();i!=Writer.end();++i)
      for (j=i,++j;j!=Writer.end();++j)
      {  if (i->second==j->second)
         {  std::cout << i->first << " and " << j->first << " share the same writer\n";
         }
      }
   return 0;
}

#include "Configuration.hh"

struct Configuration Configuration;

// ok, strictly this does not belong here ...

ostream &operator<<(ostream &o, const Pkg_Version &v)
{  return o << v.mymajor << '.' << v.myminor << '.' << v.mymicro;
}
